summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmgraphicalobjectedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmgraphicalobjectedit.h')
-rw-r--r--kpovmodeler/pmgraphicalobjectedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmgraphicalobjectedit.h b/kpovmodeler/pmgraphicalobjectedit.h
index 29f53a0f..36758f63 100644
--- a/kpovmodeler/pmgraphicalobjectedit.h
+++ b/kpovmodeler/pmgraphicalobjectedit.h
@@ -37,12 +37,13 @@ class TQLabel;
class PMGraphicalObjectEdit : public PMDetailObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDetailObjectEdit Base;
public:
/**
* Creates a PMGraphicalObjectEdit with parent and name
*/
- PMGraphicalObjectEdit( TQWidget* parent, const char* name = 0 );
+ PMGraphicalObjectEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -37,12 +37,13 @@ class TQLabel;
public:
/**
- * Creates a PMGraphicalObjectEdit with parent and name
+ * Creates a PMGraphicalObjectEdit with tqparent and name
*/